==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/batch/kotlin/inputs/UserIdentityArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.batch.kotlin.inputs

import com.pulumi.azurenative.batch.inputs.UserIdentityArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Specify either the userName or autoUser property, but not both.
 * @property autoUser The userName and autoUser properties are mutually exclusive; you must specify one but not both.
 * @property userName The userName and autoUser properties are mutually exclusive; you must specify one but not both.
 */
public data class UserIdentityArgs(
    public val autoUser: Output<AutoUserSpecificationArgs>? = null,
    public val userName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.batch.inputs.UserIdentityArgs> {
    override fun toJava(): com.pulumi.azurenative.batch.inputs.UserIdentityArgs =
        com.pulumi.azurenative.batch.inputs.UserIdentityArgs.builder()
            .autoUser(autoUser?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .userName(userName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UserIdentityArgs].
 */
@PulumiTagMarker
public class UserIdentityArgsBuilder internal constructor() {
    private var autoUser: Output<AutoUserSpecificationArgs>? = null

    private var userName: Output<String>? = null

    /**
     * @param value The userName and autoUser properties are mutually exclusive; you must specify one but not both.
     */
    @JvmName("chxcohveeynchprl")
    public suspend fun autoUser(`value`: Output<AutoUserSpecificationArgs>) {
        this.autoUser = value
    }

    /**
     * @param value The userName and autoUser properties are mutually exclusive; you must specify one but not both.
     */
    @JvmName("aeavrxrahnchjjtl")
    public suspend fun userName(`value`: Output<String>) {
        this.userName = value
    }

    /**
     * @param value The userName and autoUser properties are mutually exclusive; you must specify one but not both.
     */
    @JvmName("xacmmepbpuuuhcfm")
    public suspend fun autoUser(`value`: AutoUserSpecificationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.autoUser = mapped
    }

    /**
     * @param argument The userName and autoUser properties are mutually exclusive; you must specify one but not both.
     */
    @JvmName("nxcqsupfffdmfgjr")
    public suspend fun autoUser(argument: suspend AutoUserSpecificationArgsBuilder.() -> Unit) {
        val toBeMapped = AutoUserSpecificationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.autoUser = mapped
    }

    /**
     * @param value The userName and autoUser properties are mutually exclusive; you must specify one but not both.
     */
    @JvmName("pbmvqthqwobselyj")
    public suspend fun userName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userName = mapped
    }

    internal fun build(): UserIdentityArgs = UserIdentityArgs(
        autoUser = autoUser,
        userName = userName,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/batch/kotlin/inputs/UserIdentityArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.batch.kotlin.inputs

import com.pulumi.azurenative.batch.inputs.UserIdentityArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Specify either the userName or autoUser property, but not both.
 * @property autoUser The userName and autoUser properties are mutually exclusive; you must specify one but not both.
 * @property userName The userName and autoUser properties are mutually exclusive; you must specify one but not both.
 */
public data class UserIdentityArgs(
    public val autoUser: Output<AutoUserSpecificationArgs>? = null,
    public val userName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.batch.inputs.UserIdentityArgs> {
    override fun toJava(): com.pulumi.azurenative.batch.inputs.UserIdentityArgs =
        com.pulumi.azurenative.batch.inputs.UserIdentityArgs.builder()
            .autoUser(autoUser?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .userName(userName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UserIdentityArgs].
 */
@PulumiTagMarker
public class UserIdentityArgsBuilder internal constructor() {
    private var autoUser: Output<AutoUserSpecificationArgs>? = null

    private var userName: Output<String>? = null

    /**
     * @param value The userName and autoUser properties are mutually exclusive; you must specify one but not both.
     */
    @JvmName("paiplnnrowdkpexb")
    public suspend fun autoUser(`value`: Output<AutoUserSpecificationArgs>) {
        this.autoUser = value
    }

    /**
     * @param value The userName and autoUser properties are mutually exclusive; you must specify one but not both.
     */
    @JvmName("wdajychnnxhcbjpx")
    public suspend fun userName(`value`: Output<String>) {
        this.userName = value
    }

    /**
     * @param value The userName and autoUser properties are mutually exclusive; you must specify one but not both.
     */
    @JvmName("udaucgicvldliyfl")
    public suspend fun autoUser(`value`: AutoUserSpecificationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.autoUser = mapped
    }

    /**
     * @param argument The userName and autoUser properties are mutually exclusive; you must specify one but not both.
     */
    @JvmName("yybqjhdwemvpttmo")
    public suspend fun autoUser(argument: suspend AutoUserSpecificationArgsBuilder.() -> Unit) {
        val toBeMapped = AutoUserSpecificationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.autoUser = mapped
    }

    /**
     * @param value The userName and autoUser properties are mutually exclusive; you must specify one but not both.
     */
    @JvmName("nqssxliefgojbwpx")
    public suspend fun userName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userName = mapped
    }

    internal fun build(): UserIdentityArgs = UserIdentityArgs(
        autoUser = autoUser,
        userName = userName,
    )
}
